package org.beanizer.jxosd;

/**
 *	Class to create an On Screen Display.
 *	<div>
 *	<p>
 *  This class is a Java binding of the useful native XOSD library (<a href="http://www.ignavus.net/software.html">http://www.ignavus.net/software.html</a>).<br>
 *	As XOSD author explains:<br>
 *	"XOSD displays text on your screen, sounds simple right? 
 *	The difference is it is unmanaged and shaped, 
 *	so it appears transparent. This gives the effect of an On Screen Display, like your TV/VCR etc.". 
 *<br>
 *<br>
 *	Typical Usage:<br>
 *	&nbsp;&nbsp;&nbsp;	libxosd.so and libjxosd.so must be in java.library.path or LD_LIBRARY_PATH.
 *	<br><br>
 *	&nbsp;&nbsp;&nbsp;	A simple example		
 *<br><br>
 *	&nbsp;&nbsp;&nbsp;	JXosd x = new JXosd(2);										// creates 2 lines display<br>
 *	&nbsp;&nbsp;&nbsp;	x.setPosition(JXosd.TOP);									// vertical position<br>
 *	&nbsp;&nbsp;&nbsp;	x.setTimeout(5);											// 5 seconds of display time<br>
 *	&nbsp;&nbsp;&nbsp;	x.setColor("MediumSpringGreen");							// see following notices<br>
 *	&nbsp;&nbsp;&nbsp;	x.setFont("-misc-fixed-bold-r-normal--15-*-*-*-c-*-*-*");	// see following notices<br>
 *	&nbsp;&nbsp;&nbsp;	x.setShadowOffset(1);										// shadow offset in pixels<br>
 *	&nbsp;&nbsp;&nbsp;	x.setShadowColor("gray");									// shadow color<br>
 *	&nbsp;&nbsp;&nbsp;	x.showText(0, "This is a test string........");				// text to show on line 0<br>
 *	&nbsp;&nbsp;&nbsp;	x.waitUntilNoDisplay();										// wait<br>
 *	&nbsp;&nbsp;&nbsp;	x.destroy();												// finalize<br>
 *<br><br>
 *	&nbsp;&nbsp;&nbsp;	You can also use showPercentage or showSlider.
 *<br><br>
 *	&nbsp;NOTICE ABOUT COLOURS:<br>
 *	&nbsp;&nbsp;&nbsp;	Colours string are those you can find in the rgb.txt file in your X11 distribution
 *<br><br>
 *	&nbsp;NOTICE ABOUT FONTS:<br>
 *	&nbsp;&nbsp;&nbsp;	Use xfontsel or xlsfont to get a list of fonts
 *<br>
 *<br>
 </p>
 *@author     Mauro Molino
 *@created    07 September 2004
 */
public class JXosd {
	
	public static final int SUCCESS=0;
	public static final int FAILURE=-1;

	public static final int HIDDEN=0;
	public static final int SHOWN=1;

	public static final int TOP=0;
	public static final int BOTTOM=1;
	public static final int MIDDLE=2;

	public static final int LEFT=0;
	public static final int CENTER=1;
	public static final int RIGHT=2;
	
	/**
	 *  Constructor for the JXosd object
	 *
	 *@param  lines  Number of lines for the display
	 */
	public JXosd(int lines) {
		this.initialize(lines);
	}


	/**
	 *  Creates the native object
	 *
	 *@param  lines  Number of lines of the display
	 */
	private native void initialize(int lines);


	/**
	 *  Destroys the native object
	 *
	 *@return    SUCCESS or FAILURE
	 */
	public native int destroy();


	/**
	 *  Makes the display visible.
	 *
	 *@return	SUCCESS or FAILURE    
	 */
	public native int show();


	/**
	 *  Hides the display
	 *
	 *@return    SUCCESS or FAILURE
	 */
	public native int hide();


	/**
	 *  Gets the number of  lines of the display
	 *
	 *@return    The number of lines of the display
	 */
	public native int getNumberLines();


	/**
	 *  Gets the onScreen status of the display
	 *
	 *@return    SHOWN, HIDDEN or FAILURE
	 */
	public native int isOnScreen();


	/**
	 *  Waits until display is empty
	 *
	 *@return    SUCCESS or FAILURE
	 */
	public native int waitUntilNoDisplay();


	/**
	 *  Sets the nymber of seconds before the display is hidden 
	 *
	 *@param  timeout number of seconds
	 */
	public native void setTimeout(int timeout);


	/**
	 *  Sets the vertical position of the display
	 *
	 *@param  pos  TOP, BOTTOM, MIDDLE
	 *@return      SUCCESS or FAILURE
	 */
	public native int setPosition(int pos);


	/**
	 *  Sets the horizontal alignment of the display
	 *
	 *@param  pos  LEFT, CENTER or RIGHT
	 *@return      SUCCESS or FAILURE
	 */
	public native int setAlign(int pos);


	/**
	 *  Sets the bar length(for percentage or slider) 
	 *
	 *@param  length  length in pixels 
	 */
	public native void setBarLength(int length);


	/**
	 *  Sets the foreground color
	 *
	 *@param  color  The new color
	 *@return        SUCCESS or FAILURE
	 */
	public native int setColor(String color);


	/**
	 *  Sets the font
	 *@param  font  The new font
	 *@return       SUCCESS or FAILURE
	 */
	public native int setFont(String font);


	/**
	 *  Sets the outline color
	 *
	 *@param  color  The new outline color
	 *@return        SUCCESS or FAILURE
	 */
	public native int setOutlineColor(String color);


	/**
	 *  Sets the outline offset
	 *
	 *@param  offset  The new outline offset
	 *@return         SUCCESS or FAILURE
	 */
	public native int setOutlineOffset(int offset);


	/**
	 *  Sets the shadow color
	 *
	 *@param  color  The new shadow color
	 *@return        SUCCESS or FAILURE
	 */
	public native int setShadowColor(String color);


	/**
	 *  Sets the shadow offset
	 *
	 *@param  offset  The new shadow offset
	 *@return         SUCCESS or FAILURE
	 */
	public native int setShadowOffset(int offset);


	/**
	 *  Sets the horizontal offset
	 *
	 *@param  offset  The new horizontal offset value
	 *@return         SUCCESS or FAILURE
	 */
	public native int setHorizontalOffset(int offset);


	/**
	 *  Sets the vertical offset
	 *
	 *@param  offset  The new vertical offset
	 *@return         SUCCESS or FAILURE
	 */
	public native int setVerticalOffset(int offset);


	/**
	 *  Show given text
	 *
	 *@param  line  Line of the display where to show text
	 *@param  text  Text string
	 *@return       SUCCESS or FAILURE
	 */
	public native int showText(int line, String text);


	/**
	 *  Description of the Method
	 *
	 *@param  line   Line of the display where to show the percentage bar
	 *@param  value  Value to show
	 *@return        SUCCESS or FAILURE
	 */
	public native int showPercentage(int line, int value);


	/**
	 *  Description of the Method
	 *
	 *@param  line   Line of the display where to show the slider
	 *@param  value  Value to show
	 *@return        SUCCESS or FAILURE
	 */
	public native int showSlider(int line, int value);


	/**
	 *  Scrolls th display a given number of lines
	 *
	 *@param  lines  Bunber of lines to scroll
	 *@return        SUCCESS or FAILURE
	 */
	public native int scroll(int lines);


	static {
		System.loadLibrary("jxosd");
	}
}

